function [z , PSD] = artificial_surf1d_phaseC_4TU(Cq0, H, Lx, m1, q0, qr,qS,qC)
% Generates 1D artifial fractal topographies with different fractal
% dimensions and parameters.
% Created by A. Lee - 01/29/19

% =========================================================================

% Lx = m * PixelWidth; % image length in x direction
% Wavevectors (note that q = (2*pi) / lambda; where lambda is wavelength.

% =========================================================================


Fs = m1/Lx; % spatial frequency (wavelength)

for k = 0:m1/2-1
    qx(k+1) = Fs * (k) / m1; 
end

% =========================================================================
% handle qr case
 if ~exist('qr','var')
     % default qr
      qr = 0; % no roll-off
 end

%% 2D matrix of Cq values 

Cq = zeros(1,m1/2); % power spectral density
S = 2*H+1; % spectra slope
C=log10(Cq0)+S*log10(qr); 
Cq1 = 10^(-S*log10(qS)+C);

% Tail 
S0 = 2;
C0=(log10(Cq1))+S0*(log10(qS));

for i = 1:m1/2
    if qx(1,i) < q0
        Cq(1,i) = 0;
    elseif qx(1,i) <= qr
        Cq(1,i) = Cq0;
    elseif qx(1,i) <= qS
        Cq(1,i) = 10^(-S*log10(qx(1,i))+C);        
    elseif qx(1,i) <= qC
        Cq(1,i) = 10^(-S0*log10(qx(1,i))+C0);
    else
        Cq(1,i) = 0;
    end

end

% =========================================================================

%% Amplitude and phase
Bq = sqrt(Cq*Lx)*Fs ;
phi = zeros(1,m1/2);

ind0 = find(abs(qx-qS)==min(abs(qx-qS)));
ind0 = ind0(1);

%% phi linear trend
load PSD_4TU
phi(1,1:ind0)= PSD.phi(1:ind0); % phase w/ large var.: from measurement data
phi(1,ind0:m1/2) = linspace(-1.5,0,length(ind0:m1/2)) ...
    -pi/8+ (pi/4)*rand(1,length(ind0:m1/2)); % phase w/ small var.

%% duplicate to other part
Bq(1,1) = 0;
Bq(1,m1/2+1) = 0;
Bq(1,m1/2+2:m1) = flip(Bq(1,2:m1/2),2);

%% phase
phi(1,1) = 0;
phi(1,m1/2+1) = 0;
phi(1,m1/2+2:m1) = -flip(phi(1,2:m1/2),2);


%% inverse fft
[a,b] = pol2cart(phi,Bq);
Hq = complex(a,b);
z = real(ifft(Hq));

PSD.qx = qx;
PSD.Bq = Bq;
PSD.Cq = Cq;
PSD.phi = phi;


